## 0.10.6 (2022-04-27)

Remove Python 2 support from toml (#7713)

## 0.10.5 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 0.10.4 (2022-02-10)

Improve `toml` typings (#7146)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 0.10.3 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 0.10.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 0.10.0 (2021-09-19)

Update third-party package versions (#5996)

